@@ -122,7 +122,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -138,16 +138,16 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_apigateway
-import aws_cdk.aws_iam
-import aws_cdk.aws_kms
-import aws_cdk.aws_logs
-import aws_cdk.aws_sqs
-import constructs
+import aws_cdk.aws_apigateway as _aws_cdk_aws_apigateway_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import aws_cdk.aws_kms as _aws_cdk_aws_kms_ceddda9d
+import aws_cdk.aws_logs as _aws_cdk_aws_logs_ceddda9d
+import aws_cdk.aws_sqs as _aws_cdk_aws_sqs_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class ApiGatewayToSqs(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-apigateway-sqs.ApiGatewayToSqs",
 ):
@@ -157,7 +157,7 @@ class ApiGatewayToSqs(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         allow_create_operation: typing.Optional[builtins.bool] = None,
@@ -165,16 +165,16 @@ class ApiGatewayToSqs(
         allow_read_operation: typing.Optional[builtins.bool] = None,
         api_gateway_props: typing.Any = None,
         create_request_template: typing.Optional[builtins.str] = None,
-        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        dead_letter_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
         delete_request_template: typing.Optional[builtins.str] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-        existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_queue_obj: typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue] = None,
+        log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
         read_request_template: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -202,29 +202,7 @@ class ApiGatewayToSqs(
         :summary: Constructs a new instance of the ApiGatewayToSqs class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                allow_create_operation: typing.Optional[builtins.bool] = None,
-                allow_delete_operation: typing.Optional[builtins.bool] = None,
-                allow_read_operation: typing.Optional[builtins.bool] = None,
-                api_gateway_props: typing.Any = None,
-                create_request_template: typing.Optional[builtins.str] = None,
-                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                delete_request_template: typing.Optional[builtins.str] = None,
-                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
-                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-                max_receive_count: typing.Optional[jsii.Number] = None,
-                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                read_request_template: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__09ecc354d79c3e48682fe4f327af488b07fbaae3ff1c1533d46af5a4fb29bc03)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToSqsProps(
@@ -250,33 +228,37 @@ class ApiGatewayToSqs(
 
     @builtins.property
     @jsii.member(jsii_name="apiGateway")
-    def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
-        return typing.cast(aws_cdk.aws_apigateway.RestApi, jsii.get(self, "apiGateway"))
+    def api_gateway(self) -> _aws_cdk_aws_apigateway_ceddda9d.RestApi:
+        return typing.cast(_aws_cdk_aws_apigateway_ceddda9d.RestApi, jsii.get(self, "apiGateway"))
 
     @builtins.property
     @jsii.member(jsii_name="apiGatewayLogGroup")
-    def api_gateway_log_group(self) -> aws_cdk.aws_logs.LogGroup:
-        return typing.cast(aws_cdk.aws_logs.LogGroup, jsii.get(self, "apiGatewayLogGroup"))
+    def api_gateway_log_group(self) -> _aws_cdk_aws_logs_ceddda9d.LogGroup:
+        return typing.cast(_aws_cdk_aws_logs_ceddda9d.LogGroup, jsii.get(self, "apiGatewayLogGroup"))
 
     @builtins.property
     @jsii.member(jsii_name="apiGatewayRole")
-    def api_gateway_role(self) -> aws_cdk.aws_iam.Role:
-        return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "apiGatewayRole"))
+    def api_gateway_role(self) -> _aws_cdk_aws_iam_ceddda9d.Role:
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.Role, jsii.get(self, "apiGatewayRole"))
 
     @builtins.property
     @jsii.member(jsii_name="sqsQueue")
-    def sqs_queue(self) -> aws_cdk.aws_sqs.Queue:
-        return typing.cast(aws_cdk.aws_sqs.Queue, jsii.get(self, "sqsQueue"))
+    def sqs_queue(self) -> _aws_cdk_aws_sqs_ceddda9d.Queue:
+        return typing.cast(_aws_cdk_aws_sqs_ceddda9d.Queue, jsii.get(self, "sqsQueue"))
 
     @builtins.property
     @jsii.member(jsii_name="apiGatewayCloudWatchRole")
-    def api_gateway_cloud_watch_role(self) -> typing.Optional[aws_cdk.aws_iam.Role]:
-        return typing.cast(typing.Optional[aws_cdk.aws_iam.Role], jsii.get(self, "apiGatewayCloudWatchRole"))
+    def api_gateway_cloud_watch_role(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_iam_ceddda9d.Role]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_iam_ceddda9d.Role], jsii.get(self, "apiGatewayCloudWatchRole"))
 
     @builtins.property
     @jsii.member(jsii_name="deadLetterQueue")
-    def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue]:
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue], jsii.get(self, "deadLetterQueue"))
+    def dead_letter_queue(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.DeadLetterQueue]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.DeadLetterQueue], jsii.get(self, "deadLetterQueue"))
 
 
 @jsii.data_type(
@@ -310,16 +292,16 @@ class ApiGatewayToSqsProps:
         allow_read_operation: typing.Optional[builtins.bool] = None,
         api_gateway_props: typing.Any = None,
         create_request_template: typing.Optional[builtins.str] = None,
-        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        dead_letter_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
         delete_request_template: typing.Optional[builtins.str] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-        existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_queue_obj: typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue] = None,
+        log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
         read_request_template: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -343,35 +325,15 @@ class ApiGatewayToSqsProps:
         :summary: The properties for the ApiGatewayToSqs class.
         '''
         if isinstance(dead_letter_queue_props, dict):
-            dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
+            dead_letter_queue_props = _aws_cdk_aws_sqs_ceddda9d.QueueProps(**dead_letter_queue_props)
         if isinstance(encryption_key_props, dict):
-            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
+            encryption_key_props = _aws_cdk_aws_kms_ceddda9d.KeyProps(**encryption_key_props)
         if isinstance(log_group_props, dict):
-            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+            log_group_props = _aws_cdk_aws_logs_ceddda9d.LogGroupProps(**log_group_props)
         if isinstance(queue_props, dict):
-            queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
+            queue_props = _aws_cdk_aws_sqs_ceddda9d.QueueProps(**queue_props)
         if __debug__:
-            def stub(
-                *,
-                allow_create_operation: typing.Optional[builtins.bool] = None,
-                allow_delete_operation: typing.Optional[builtins.bool] = None,
-                allow_read_operation: typing.Optional[builtins.bool] = None,
-                api_gateway_props: typing.Any = None,
-                create_request_template: typing.Optional[builtins.str] = None,
-                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                delete_request_template: typing.Optional[builtins.str] = None,
-                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
-                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-                max_receive_count: typing.Optional[jsii.Number] = None,
-                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                read_request_template: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0b4d5e44aa1091822c16f5f2ee960065e35aa980d66f3bc2142bc7d44ed15fde)
             check_type(argname="argument allow_create_operation", value=allow_create_operation, expected_type=type_hints["allow_create_operation"])
             check_type(argname="argument allow_delete_operation", value=allow_delete_operation, expected_type=type_hints["allow_delete_operation"])
             check_type(argname="argument allow_read_operation", value=allow_read_operation, expected_type=type_hints["allow_read_operation"])
@@ -388,7 +350,7 @@ class ApiGatewayToSqsProps:
             check_type(argname="argument max_receive_count", value=max_receive_count, expected_type=type_hints["max_receive_count"])
             check_type(argname="argument queue_props", value=queue_props, expected_type=type_hints["queue_props"])
             check_type(argname="argument read_request_template", value=read_request_template, expected_type=type_hints["read_request_template"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if allow_create_operation is not None:
             self._values["allow_create_operation"] = allow_create_operation
         if allow_delete_operation is not None:
@@ -468,13 +430,15 @@ class ApiGatewayToSqsProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def dead_letter_queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
+    def dead_letter_queue_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps]:
         '''Optional user provided properties for the dead letter queue.
 
         :default: - Default props are used
         '''
         result = self._values.get("dead_letter_queue_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.QueueProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps], result)
 
     @builtins.property
     def delete_request_template(self) -> typing.Optional[builtins.str]:
@@ -508,40 +472,44 @@ class ApiGatewayToSqsProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
+    def encryption_key(self) -> typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key]:
         '''An optional, imported encryption key to encrypt the SQS Queue with.
 
         :default: - None
         '''
         result = self._values.get("encryption_key")
-        return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key], result)
 
     @builtins.property
-    def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
+    def encryption_key_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_kms_ceddda9d.KeyProps]:
         '''Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS queue with.
 
         :default: - None
         '''
         result = self._values.get("encryption_key_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_kms.KeyProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kms_ceddda9d.KeyProps], result)
 
     @builtins.property
-    def existing_queue_obj(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
+    def existing_queue_obj(self) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue]:
         '''Existing instance of SQS queue object, providing both this  and queueProps will cause an error.
 
         :default: - None
         '''
         result = self._values.get("existing_queue_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.Queue], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue], result)
 
     @builtins.property
-    def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
+    def log_group_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_logs_ceddda9d.LogGroupProps]:
         '''User provided props to override the default props for the CloudWatchLogs LogGroup.
 
         :default: - Default props are used
         '''
         result = self._values.get("log_group_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_logs.LogGroupProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_logs_ceddda9d.LogGroupProps], result)
 
     @builtins.property
     def max_receive_count(self) -> typing.Optional[jsii.Number]:
@@ -553,13 +521,13 @@ class ApiGatewayToSqsProps:
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
+    def queue_props(self) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps]:
         '''User provided props to override the default props for the SQS queue.
 
         :default: - Default props are used
         '''
         result = self._values.get("queue_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.QueueProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps], result)
 
     @builtins.property
     def read_request_template(self) -> typing.Optional[builtins.str]:
@@ -588,3 +556,49 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__09ecc354d79c3e48682fe4f327af488b07fbaae3ff1c1533d46af5a4fb29bc03(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    allow_create_operation: typing.Optional[builtins.bool] = None,
+    allow_delete_operation: typing.Optional[builtins.bool] = None,
+    allow_read_operation: typing.Optional[builtins.bool] = None,
+    api_gateway_props: typing.Any = None,
+    create_request_template: typing.Optional[builtins.str] = None,
+    dead_letter_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    delete_request_template: typing.Optional[builtins.str] = None,
+    deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+    enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+    encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+    encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_queue_obj: typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue] = None,
+    log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    max_receive_count: typing.Optional[jsii.Number] = None,
+    queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    read_request_template: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0b4d5e44aa1091822c16f5f2ee960065e35aa980d66f3bc2142bc7d44ed15fde(
+    *,
+    allow_create_operation: typing.Optional[builtins.bool] = None,
+    allow_delete_operation: typing.Optional[builtins.bool] = None,
+    allow_read_operation: typing.Optional[builtins.bool] = None,
+    api_gateway_props: typing.Any = None,
+    create_request_template: typing.Optional[builtins.str] = None,
+    dead_letter_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    delete_request_template: typing.Optional[builtins.str] = None,
+    deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+    enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+    encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+    encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_queue_obj: typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue] = None,
+    log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    max_receive_count: typing.Optional[jsii.Number] = None,
+    queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    read_request_template: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
